Stan Math Library: stan/math/rev/scal/fun/if_else.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

if_else.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_SCAL_FUN_IF_ELSE_HPP
2 #define STAN_MATH_REV_SCAL_FUN_IF_ELSE_HPP
3
4 #include <stan/math/rev/core.hpp>
5
6 namespace stan {
7 namespace math {
8
17 inline var if_else(bool c, const var& y_true, const var&y_false) {
18 return c ? y_true : y_false;
19 }
29 inline var if_else(bool c, double y_true, const var& y_false) {
30 if (c)
31 return var(y_true);
32 else
33 return y_false;
34 }
44 inline var if_else(bool c, const var& y_true, const double y_false) {
45 if (c)
46 return y_true;
47 else
48 return var(y_false);
49 }
50
51 }
52 }
53 #endif
core.hpp
stan
Definition: log_sum_exp.hpp:8
stan::math::var
Independent (input) and dependent (output) variables for gradients.
Definition: var.hpp:31
stan::math::if_else
boost::math::tools::promote_args< T_true, T_false >::type if_else(const bool c, const T_true y_true, const T_false y_false)
Return the second argument if the first argument is true and otherwise return the second argument...
Definition: if_else.hpp:25

[ Stan Home Page ] © 2011–2016, Stan Development Team.